.. _api:

API Reference
=============
|

The StreamSets DataOps Platform SDK for Python has abstractions for interacting with StreamSets DataOps Platform.

.. toctree::
   :maxdepth: 2

   api/sch_api
